@@ -1,7 +1,7 @@
 package Module::DataPack;
 
 our $DATE = '2015-10-21'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -193,7 +193,7 @@ sub datapack_modules {
             read DATA, my($content), $toc->{$_[1]}[1];
             my ($order, $lineoffset) = split(';', $toc->{$_[1]}[2]);
             $content =~ s/^ //gm;
-            $content = "# line ".($data_linepos + 1 + $order+1 + $lineoffset)." \"".__FILE__."\"\n" . $content;
+            $content = "# line ".($data_linepos + $order+1 + $lineoffset)." \"".__FILE__."\"\n" . $content;
             open my $fh, '<', \$content
                 or die "DataPacker error loading $_[1]: $!";
             return $fh;
@@ -254,7 +254,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.14 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-10-21.
+This document describes version 0.15 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-10-21.
 
 =head1 SEE ALSO
 
